@@ -221,7 +221,7 @@ class StreamingGateway:
 
         logging.info("Stopping all active streams...")
 
-    def start_streaming(self) -> bool:
+    def start_streaming(self, send_to_api: bool = False) -> bool:
         """Start streaming using MatriceDeployClient's built-in capabilities.
 
         Returns:
@@ -316,7 +316,7 @@ class StreamingGateway:
             # Start result consumption thread if we have output config or callback
             if self.output_config or self.result_callback:
                 self.result_thread = threading.Thread(
-                    target=self._consume_results, daemon=True, name="ResultConsumer"
+                    target=self._consume_results, daemon=True, name="ResultConsumer", args=(send_to_api,)
                 )
                 self.result_thread.start()
 
@@ -490,10 +490,10 @@ class StreamingGateway:
             force_restart=config.get("force_restart", False),
         )
 
-    def _consume_results(self):
+    def _consume_results(self, send_to_api: bool = False):
         """Consume and process results from the deployment."""
         if self.results_handler:
-            self.results_handler._consume_results()
+            self.results_handler._consume_results(send_to_api=send_to_api)
         else:
             logging.warning("No results handler available for result consumption")
 
