@@ -36,6 +36,7 @@ APP_NAME_TO_USECASE = {
     "car_damage_detection": "car_damage_detection",
     "license_plate_detection": "license_plate_detection",
     "shoplifting_detection": "shoplifting_detection",
+    "cardiomegaly_classification": "cardiomegaly_classification",
 }
 
 APP_NAME_TO_CATEGORY = {
@@ -76,6 +77,7 @@ APP_NAME_TO_CATEGORY = {
     "car_damage_detection": "car_damage",
     "license_plate_detection": "license_plate",
     "shoplifting_detection": "security",
+    "cardiomegaly_classification": "healthcare",
 }
 
 def get_usecase_from_app_name(app_name: str) -> str:
