@@ -67,6 +67,7 @@ from .smoker_detection import SmokerDetectionConfig, SmokerDetectionUseCase
 from .blood_cancer_detection_img import BloodCancerDetectionConfig, BloodCancerDetectionUseCase
 from .skin_cancer_classification_img import SkinCancerClassificationConfig, SkinCancerClassificationUseCase
 from .plaque_segmentation_img import PlaqueSegmentationConfig, PlaqueSegmentationUseCase
+from .cardiomegaly_classification import CardiomegalyConfig, CardiomegalyUseCase
 
 __all__ = [
     'PeopleCountingUseCase',
@@ -124,6 +125,7 @@ __all__ = [
     'BloodCancerDetectionUseCase',
     'SkinCancerClassificationUseCase',
     'PlaqueSegmentationUseCase',
+    'CardiomegalyUseCase',
 
 
 
@@ -184,6 +186,7 @@ __all__ = [
     'BloodCancerDetectionConfig',
     'SkinCancerClassificationConfig',
     'PlaqueSegmentationConfig',
+    'CardiomegalyConfig',
 
 
 ]
\ No newline at end of file
