@@ -189,8 +189,7 @@ class FireSmokeUseCase(BaseProcessor):
                     frame_number = start_frame
 
              # Step 7: alerts
-            print("-----------ALERT_PROCESSING_IPP-----------")
-            print(fire_smoke_summary)
+
             alerts = self._check_alerts(fire_smoke_summary, frame_number, config, stream_info)
 
 
@@ -272,10 +271,6 @@ class FireSmokeUseCase(BaseProcessor):
         by_category = summary.get("by_category", {})
         detections = summary.get("detections", [])
         frame_key = str(frame_number) if frame_number is not None else "current_frame"
-        print("-----------ALERTTTTTTTTTTTTSSSSS-----------")
-        print(hasattr(config.alert_config, 'count_thresholds'), config.alert_config.count_thresholds)
-        print(total)
-        print(summary.get("per_category_count", {}))
 
         if total == 0:
             return []
@@ -287,7 +282,7 @@ class FireSmokeUseCase(BaseProcessor):
 
             for category, threshold in config.alert_config.count_thresholds.items():
                 if category == "all" and total > threshold:  
-                    print("-----------ALERTS--INNN-----------")
+                    
                     alerts.append({
                         "alert_type": getattr(config.alert_config, 'alert_type', ['Default']) if hasattr(config.alert_config, 'alert_type') else ['Default'],
                         "alert_id": "alert_"+category+'_'+frame_key,
@@ -299,7 +294,7 @@ class FireSmokeUseCase(BaseProcessor):
                                     }                    
                     })
                 elif category in summary.get("per_category_count", {}):
-                    print("-----------ALERTS--INNN 2-----------")
+                    
                     count = summary.get("per_category_count", {})[category]
                     if count > threshold:  # Fixed logic: alert when EXCEEDING threshold
                         alerts.append({
@@ -359,9 +354,6 @@ class FireSmokeUseCase(BaseProcessor):
         camera_info = self.get_camera_info_from_stream(stream_info)
         self._ascending_alert_list = self._ascending_alert_list[-5000:] if len(self._ascending_alert_list) > 5000 else self._ascending_alert_list
         levels_list = ["low","medium","significant","critical"]
-        print("-----------INCIDENTS-----------")
-        print(total)
-        print(summary.get("per_category_count", {}))
 
         if total > 0:
            # Calculate total bbox area
@@ -369,7 +361,7 @@ class FireSmokeUseCase(BaseProcessor):
 
             for category, threshold in config.alert_config.count_thresholds.items():
                 if category in summary.get("per_category_count", {}):
-                    print("-----------INCIDENTSS--INNN-----------")
+                    
                     #count = summary.get("per_category_count", {})[category]
                     start_timestamp = self._get_start_timestamp_str(stream_info)
                     if start_timestamp and self.current_incident_end_timestamp=='N/A':
@@ -919,7 +911,6 @@ class FireSmokeUseCase(BaseProcessor):
 
         # Return None if invalid
         if start_dt is None or end_dt is None:
-            print("Invalid timestamp(s). Ignoring.")
             return 'N/A'
 
         # If timedelta (relative time), subtract directly
@@ -928,7 +919,6 @@ class FireSmokeUseCase(BaseProcessor):
         elif isinstance(start_dt, datetime) and isinstance(end_dt, datetime):
             delta = end_dt - start_dt
         else:
-            print("Mismatched timestamp formats.")
             return None
 
         return delta.total_seconds()
